@@ -1,5 +1,7 @@
+from typing import Any, Optional
+
 from bender.evaluator.confusion_matrix import ConfusionMatrix
-from bender.evaluator.correlation_matrix import CorrelationMatrix
+from bender.evaluator.difference_distribution import DifferenceDistribution, DifferenceMetric
 from bender.evaluator.feature_importance import XGBoostFeatureImportance
 from bender.evaluator.precision_recall import PrecisionRecall
 from bender.evaluator.predict_probability import ProbabilityForClassification
@@ -17,12 +19,10 @@ class Evaluators:
         return ConfusionMatrix(exporter)
 
     @staticmethod
-    def correlation_matrix(exporter: Exporter = Exporter.in_memory()) -> CorrelationMatrix:
-        return CorrelationMatrix(exporter)
-
-    @staticmethod
-    def probability_for(classification: str, exporter: Exporter = Exporter.in_memory()) -> ProbabilityForClassification:
-        return ProbabilityForClassification(exporter, classification)
+    def probability_for(
+        classification: Optional[Any] = None, num_bins: Optional[int] = None, exporter: Exporter = Exporter.in_memory()
+    ) -> ProbabilityForClassification:
+        return ProbabilityForClassification(exporter, classification, num_bins)
 
     @staticmethod
     def feature_importance(exporter: Exporter = Exporter.in_memory()) -> XGBoostFeatureImportance:
@@ -31,3 +31,9 @@ class Evaluators:
     @staticmethod
     def precision_recall(exporter: Exporter = Exporter.in_memory()) -> PrecisionRecall:
         return PrecisionRecall(exporter)
+
+    @staticmethod
+    def error_distribution(
+        metric: DifferenceMetric, exporter: Exporter = Exporter.in_memory()
+    ) -> DifferenceDistribution:
+        return DifferenceDistribution(metric, exporter)
