@@ -2,6 +2,7 @@ import pytest
 from pandas import DataFrame
 
 from bender.importers import DataImporters
+from bender.metrics import Metrics
 from bender.model_trainer.xgboosted_tree import XGBoostTrainer
 
 pytestmark = pytest.mark.asyncio
@@ -9,14 +10,16 @@ pytestmark = pytest.mark.asyncio
 
 async def test_cross_validation(date_df: DataFrame) -> None:
 
-    _ = await (
+    score = await (
         DataImporters.literal(date_df)
         .cross_validate(
             'classification',
             3,
             lambda pipeline: pipeline.train(
                 XGBoostTrainer(), input_features=['y_values', 'x_values'], target_feature='bool_classification'
-            ),
+            ).metric(Metrics.log_loss()),
         )
         .run()
     )
+
+    assert score > 0
